@@ -3,8 +3,9 @@ BEGIN {
   $Yeb::Plugin::JSON::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Yeb::Plugin::JSON::VERSION = '0.002';
+  $Yeb::Plugin::JSON::VERSION = '0.003';
 }
+# ABSTRACT: Yeb Plugin for JSON response
 
 use Moo;
 use JSON;
@@ -23,16 +24,33 @@ sub BUILD {
 }
 
 1;
+
+
 __END__
 =pod
 
 =head1 NAME
 
-Yeb::Plugin::JSON
+Yeb::Plugin::JSON - Yeb Plugin for JSON response
 
 =head1 VERSION
 
-version 0.002
+version 0.003
+
+=head1 SUPPORT
+
+IRC
+
+  Join #web-simple on irc.perl.org. Highlight Getty for fast reaction :).
+
+Repository
+
+  http://github.com/Getty/p5-yeb
+  Pull request and additional contributors are welcome
+
+Issue Tracker
+
+  http://github.com/Getty/p5-yeb/issues
 
 =head1 AUTHOR
 
